@@ -1,5 +1,5 @@
 package Net::Whois::Raw::Common;
-$Net::Whois::Raw::Common::VERSION = '2.99002';
+$Net::Whois::Raw::Common::VERSION = '2.99003';
 # ABSTRACT: Helper for Net::Whois::Raw.
 
 use Encode;
@@ -105,12 +105,9 @@ sub process_whois {
 
     if ( $CHECK_FAIL || $OMIT_MSG ) {
 
-        my %notfound = %Net::Whois::Raw::Data::notfound;
-        my %strip = %Net::Whois::Raw::Data::strip;
-
-        my $notfound = $notfound{ $server };
-
-        my @strip = $strip{ $server } ? @{ $strip{ $server } } : ();
+        my $notfound = $Net::Whois::Raw::Data::notfound{ $server };
+        my $strip = $Net::Whois::Raw::Data::strip{ $server };
+        my @strip = $strip ? @$strip : ();
         my @lines;
 
         MAIN:
@@ -620,7 +617,7 @@ Net::Whois::Raw::Common - Helper for Net::Whois::Raw.
 
 =head1 VERSION
 
-version 2.99002
+version 2.99003
 
 =head1 AUTHOR
 
